﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.RazorPages;
using Models;
using Syncfusion.EJ2.Base;

namespace AspNetCore3_EJ2_ExportExcel.Pages
{
    public class IndexModel : PageModel
    {

        public static List<Movie> Movies = new List<Movie>();

        public void OnGet()
        {

        }

        private void SeedData()
        {
            if (!Movies.Any())
            {
                string[] genres =  {
                    "Absurdist/surreal/whimsical","Action","Adventure","Comedy","Crime","Drama","Fantasy","Historical",
                    "Historical fiction","Horror","Magical realism","Mystery","Paranoid Fiction","Philosophical",
                    "Political","Romance","Saga","Satire","Science fiction","Social","Speculative","Thriller",
                    "Urban","Western"
                };

                var startDate = new DateTime(1971, 6, 26);
                var maxDays = (new DateTime(2018, 11, 6) - startDate).Days;
                var rnd = new Random();


                var movies = Enumerable.Range(1, 2000).Select(i =>
                    new Movie
                    {
                        Id = i,
                        Rating = rnd.NextDouble() * 100,
                        Title = $"Sample movie № {i}",
                        ReleaseDate = startDate.AddDays(rnd.Next(0, maxDays)),
                        Genre = genres[rnd.Next(0, genres.Count())],
                        Price = (Decimal)(rnd.NextDouble() * 10)
                    }).ToList();

                Movies.AddRange(movies);

            }
        }

        public ActionResult OnPostGet_Movies([FromBody]DataManagerRequest dm)
        {
            SeedData();
            IEnumerable data = Movies;
            DataOperations operation = new DataOperations();
            if (dm.Sorted != null && dm.Sorted.Count > 0) //Sorting
            {
                data = operation.PerformSorting(data, dm.Sorted);
            }
            if (dm.Where != null && dm.Where.Count > 0) //Filtering
            {
                data = operation.PerformFiltering(data, dm.Where, dm.Where[0].Operator);
            }
            if (dm.Search != null && dm.Search.Count > 0) //Searching
            {
                data = operation.PerformSearching(data, dm.Search);
            }
            var count = data.Cast<Movie>().Count();
            if (dm.Skip != 0)
            {
                data = operation.PerformSkip(data, dm.Skip);
            }
            if (dm.Take != 0)
            {
                data = operation.PerformTake(data, dm.Take);
            }

            return dm.RequiresCounts ? new JsonResult(new { result = data, count }) : new JsonResult(data);

        }


    }
}
